"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var utils_1 = require("../utils");
var internal_1 = require("../internal");
var templates_1 = require("../templates");
/**
 * 节点文件信息
 */
var SectionFileInfo = /** @class */ (function () {
    function SectionFileInfo(id, html, options, wordf) {
        /**
         * 编号
         */
        this.id = '';
        /**
         * 目标文件路径
         */
        this.target = '';
        /**
         * html内容
         */
        this.htmlContent = '';
        this._wordf = wordf;
        this.id = "htmlChunk" + id;
        this.target = "/word/afchunk" + id + ".mht";
        this.htmlContent = html;
        var documentOptions = internal_1.mergeOptions(internal_1.defaultDocumentOptions, options);
        var orientation = documentOptions.orientation, margins = documentOptions.margins;
        var marginsOptions = internal_1.mergeOptions(templates_1.defaultMargins, margins);
        var width = 0;
        var height = 0;
        if (orientation === 'landscape') {
            height = 12240;
            width = 15840;
        }
        else {
            width = 12240;
            height = 15840;
        }
        this._sectionOption = { height: height, width: width, orientation: orientation, marginsOptions: marginsOptions };
    }
    Object.defineProperty(SectionFileInfo.prototype, "mhtName", {
        get: function () {
            return this.target.split('/').pop();
        },
        enumerable: false,
        configurable: true
    });
    /**
     * 生成关联文件xml内容
     */
    SectionFileInfo.prototype.getRelationXml = function () {
        return "<Relationship Type='http://schemas.openxmlformats.org/officeDocument/2006/relationships/aFChunk' Target='" + this.target + "' Id='" + this.id + "' />";
    };
    /**
     * 生成MHT内容
     */
    SectionFileInfo.prototype.generalMhtDocument = function () {
        return utils_1.getMHTdocument(this.htmlContent);
    };
    /**
     * 生成document.xml文件中的openxml文本内容
     */
    SectionFileInfo.prototype.documentOPENXML = function (isLast) {
        if (isLast === void 0) { isLast = false; }
        var _a = this._sectionOption, width = _a.width, height = _a.height, orient = _a.orientation, margins = _a.marginsOptions;
        var headerXml = this.getHeaderDocumentXML(isLast);
        var footerXml = this.getFooterDocumentXML(isLast);
        var openXml = "<w:p>\n                      <w:altChunk r:id='" + this.id + "'/>\n                  </w:p>";
        var sectPr = "<w:sectPr> " + headerXml + " " + footerXml + "\n                  <w:pgSz w:w='" + width + "' w:h='" + height + "' w:orient='" + orient + "' />\n                  <w:pgMar w:top='" + margins.top + "'\n                           w:right='" + margins.right + "'\n                           w:bottom='" + margins.bottom + "'\n                           w:left='" + margins.left + "'\n                           w:header='" + margins.header + "'\n                           w:footer='" + margins.footer + "'\n                           w:gutter='" + margins.gutter + "'/>\n                </w:sectPr>";
        if (isLast) {
            return "" + openXml + sectPr;
        }
        else {
            return openXml + "\n              <w:p>\n                <w:pPr>" + sectPr + "</w:pPr>\n              </w:p>";
        }
    };
    /**
     * 生成Content_types.xml内容类型引用定义
     */
    SectionFileInfo.prototype.getContentTypeXml = function () {
        return "<Override PartName='" + this.target + "' ContentType='message/rfc822'/>";
    };
    /**
     * 获取页眉xml内容
     * @param isLast
     * @private
     */
    SectionFileInfo.prototype.getHeaderDocumentXML = function (isLast) {
        var _this = this;
        if (isLast === void 0) { isLast = false; }
        if (this._wordf.headerFile.id) {
            var curIndex = this._wordf.rFileArr.findIndex(function (r) { return r.id === _this.id; });
            if (this._wordf.headerFile.exceptSectionIdx !== -1) {
                if (curIndex === this._wordf.headerFile.exceptSectionIdx) {
                    return "<w:headerReference w:type='frist' r:id='rId-empty' />";
                }
            }
            return this._wordf.headerFile.documentOPENXML(isLast);
        }
        return '';
    };
    /**
     * 获取页脚xml内容
     * @param isLast
     * @private
     */
    SectionFileInfo.prototype.getFooterDocumentXML = function (isLast) {
        var _this = this;
        if (isLast === void 0) { isLast = false; }
        if (this._wordf.footerFile.id) {
            var curIndex = this._wordf.rFileArr.findIndex(function (r) { return r.id === _this.id; });
            if (this._wordf.footerFile.exceptSectionIdx !== -1) {
                if (curIndex === this._wordf.footerFile.exceptSectionIdx) {
                    return "<w:footerReference w:type='frist' r:id='rId-empty' />";
                }
            }
            return this._wordf.footerFile.documentOPENXML(isLast);
        }
        return '';
    };
    return SectionFileInfo;
}());
exports.default = SectionFileInfo;
