/// <reference types="node" />
/**
 * word文件类
 */
import { DocumentOptions } from '../internal';
import SectionFileInfo from './sectionFileInfo';
import HeaderFileInfo from './headerFileInfo';
import FooterFileInfo from './footerFileInfo';
export default class WordFile {
    /**
     * 文件名
     */
    fileName: string;
    /**
     * 章节关联文件
     */
    rFileArr: SectionFileInfo[];
    /**
     * 页眉
     */
    headerFile: HeaderFileInfo;
    /**
     * 页脚
     */
    footerFile: FooterFileInfo;
    constructor(name: string);
    /**
     * 新增节点
     * @param html  要导出的word文本
     * @param options  页面配置项-支持边距和纵横向设置
     */
    addSection(html: string, options?: Partial<DocumentOptions>): void;
    /**
     *  为指定的节点设置页眉
     * @param html  页眉文本内容
     * @param sectionIdx 默认为所有节点设置页眉,大于-1之后
     */
    setSectionHeader(text: string, exceptSectionIdx?: number): void;
    /**
     *  为指定的节点设置页脚
     * @param html  页眉文本内容
     * @param sectionIdx 默认为所有节点设置页眉
     */
    setSectionFooter(text: string, exceptSectionIdx?: number): void;
    /**
     * 生成word压缩包并返回异步字节流
     */
    asBlob(): Promise<Blob | Buffer>;
    /**
     * 生成文档结构
     * @private
     */
    private _generalContentTypesXml;
    /**
     * 生成关系文档内容
     * @private
     */
    private _generalRelsXml;
    private _renderDocumentFile;
}
